@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2014 by Dominique Dumont.
+# This software is Copyright (c) 2015 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application
 
 package App::Cme::Command::edit ;
-$App::Cme::Command::edit::VERSION = '1.001';
+$App::Cme::Command::edit::VERSION = '1.002';
 use strict;
 use warnings;
 use 5.10.1;
@@ -109,28 +109,7 @@ sub execute {
     elsif ( $ui_type eq 'tk' ) {
         die "cannot run Tk interface: Config::Model::TkUI is not installed\n"
             unless $has_tk;
-
-        require Tk;
-        require Tk::ErrorDialog;
-        Tk->import;
-
-        no warnings 'once';
-        my $mw = MainWindow->new;
-        $mw->withdraw;
-
-        # Thanks to Jerome Quelin for the tip
-        $mw->optionAdd( '*BorderWidth' => 1 );
-
-        my $cmu = $mw->ConfigModelUI(
-            -root       => $root,
-        );
-
-        if ($opt->{open_item}) {
-            my $obj = $root->grab($opt->{open_item});
-            $cmu->force_element_display($obj);
-        }
-
-        &MainLoop;    # Tk's
+        $self ->run_tk_ui ( $root, $opt);
     }
     else {
         die "Unsupported user interface: $ui_type";
@@ -151,7 +130,7 @@ App::Cme::Command::edit - Edit the configuration of an application
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -218,7 +197,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dominique Dumont.
+This software is Copyright (c) 2015 by Dominique Dumont.
 
 This is free software, licensed under:
 
