@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2014 by Dominique Dumont.
+# This software is Copyright (c) 2015 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Generates pod doc from model files
 
 package App::Cme::Command::gen_class_pod ;
-$App::Cme::Command::gen_class_pod::VERSION = '1.001';
+$App::Cme::Command::gen_class_pod::VERSION = '1.002';
 use strict;
 use warnings;
 use 5.10.1;
@@ -31,7 +31,8 @@ EOD
 }
 
 sub execute {
-    gen_class_pod;
+   my ($self, $opt, $args) = @_;
+   gen_class_pod(@$args);
 }
 
 1;
@@ -48,18 +49,22 @@ App::Cme::Command::gen_class_pod - Generates pod doc from model files
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
- cme gen-class-pod
+ cme gen-class-pod [ Foo ... ]
 
 =head1 DESCRIPTION
 
-This command scans C<./lib/Config/Model/models>
-and generate a pod documentation for each C<.pl> found there using
+This command scans C<./lib/Config/Model/models/*.d>
+and generate pod documentation for each file found there using
 L<Config::Model::generate_doc|Config::Model/"generate_doc ( top_class_name , [ directory ] )">
 
+You can also pass one or more class names. C<gen_class_pod> will write
+the documentation for each passed class and all other classes used by
+the passed classes.
+
 =head1 SEE ALSO
 
 L<cme>, L<Config::Model::Utils::GenClassPod>
@@ -70,7 +75,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dominique Dumont.
+This software is Copyright (c) 2015 by Dominique Dumont.
 
 This is free software, licensed under:
 
